Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(275)

Unified Diff: third_party/WebKit/Source/platform/v8_inspector/V8InjectedScriptHost.h

Issue 2199943004: [DevTools] Rename V8Debugger to V8Inspector. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/v8_inspector/V8InjectedScriptHost.h
diff --git a/third_party/WebKit/Source/platform/v8_inspector/V8InjectedScriptHost.h b/third_party/WebKit/Source/platform/v8_inspector/V8InjectedScriptHost.h
index 2b1d3ce7759eabaa22b4904e44507a84a727bcbf..38c947fd7b0c8642ddc64628bffc8f9fbadd4005 100644
--- a/third_party/WebKit/Source/platform/v8_inspector/V8InjectedScriptHost.h
+++ b/third_party/WebKit/Source/platform/v8_inspector/V8InjectedScriptHost.h
@@ -9,7 +9,7 @@
namespace blink {
-class V8DebuggerImpl;
+class V8InspectorImpl;
// SECURITY NOTE: Although the InjectedScriptHost is intended for use solely by the inspector,
// a reference to the InjectedScriptHost may be leaked to the page being inspected. Thus, the
@@ -19,8 +19,8 @@ class V8DebuggerImpl;
class V8InjectedScriptHost {
public:
// We expect that debugger outlives any JS context and thus V8InjectedScriptHost (owned by JS)
- // is destroyed before debugger.
- static v8::Local<v8::Object> create(v8::Local<v8::Context>, V8DebuggerImpl*);
+ // is destroyed before inspector.
+ static v8::Local<v8::Object> create(v8::Local<v8::Context>, V8InspectorImpl*);
private:
static void internalConstructorNameCallback(const v8::FunctionCallbackInfo<v8::Value>&);
static void formatAccessorsAsProperties(const v8::FunctionCallbackInfo<v8::Value>&);

Powered by Google App Engine
This is Rietveld 408576698